# Mutual Information

Estimating entropy and mutual information with scikit-learn.

Putting [GaelVaroquaux's mutual_info gist](https://gist.github.com/GaelVaroquaux/ead9898bd3c973c40429) in a project until it has a better home.


See `Makefile` for example ops.

Do not pin packages for now. Let's surf latest and find out when things break.

## Install

    python setup.py install

## Develop install

    python setup.py develop

## TODO

* incorporate fixes from @thismartian
* pypi
